..
   Generated: Thu Mar 23 15:03:55 2017

   @author : Eric Lapouyade

======
strops
======

.. automodule:: textops.ops.strops
.. currentmodule:: textops

StrOp
-----
   .. autoclass:: StrOp()

cut
---
   .. autoclass:: cut(sep=None, col=None, default='')

cutca
-----
   .. autoclass:: cutca(sep=None, col=None, default='')

cutdct
------
   .. autoclass:: cutdct(sep=None, col=None, default='')

cutkv
-----
   .. autoclass:: cutkv(sep=None, col=None, default='')

cutm
----
   .. autoclass:: cutm(sep=None, col=None, default='')

cutmi
-----
   .. autoclass:: cutmi(sep=None, col=None, default='')

cutre
-----
   .. autoclass:: cutre(sep=None, col=None, default='')

cuts
----
   .. autoclass:: cuts(sep=None, col=None, default='')

cutsa
-----
   .. autoclass:: cutsa(sep=None, col=None, default='')

cutsai
------
   .. autoclass:: cutsai(sep=None, col=None, default='')

cutsi
-----
   .. autoclass:: cutsi(sep=None, col=None, default='')

echo
----
   .. autoclass:: echo()

length
------
   .. autoclass:: length()

matches
-------
   .. autoclass:: matches(pattern)

searches
--------
   .. autoclass:: searches(pattern)

splitln
-------
   .. autoclass:: splitln()
